@charset "UTF-8";
/*
 * jQuery File Upload UI Plugin CSS 6.3.1
 * https://github.com/blueimp/jQuery-File-Upload
 *
 * Copyright 2010, Sebastian Tschan
 * https://blueimp.net
 *
 * Licensed under the MIT license:
 * http://www.opensource.org/licenses/MIT
 */
 
.fileinput-button {
position: relative;
overflow: hidden;
float: left;
margin-right: 4px;
}
.fileinput-button input {
position: absolute;
top: 0;
right: 0;
margin: 0;
border: solid transparent;
border-width: 0 0 100px 200px;
opacity: 0;
filter: alpha(opacity=0);
-moz-transform: translate(-300px, 0) scale(4);
direction: ltr;
cursor: pointer;
}
.fileupload-buttonbar .btn,
.fileupload-buttonbar .toggle {
margin-bottom: 5px;
}
.files .progress {
width: 20% !important;
}
.progress-animated .bar {
background: url(../img/progressbar.gif) !important;
filter: none;
}
.fileupload-loading {
position: absolute;
left: 50%;
width: 128px;
height: 128px;
background: url(../img/loading.gif) center no-repeat;
display: none;
}
.fileupload-processing .fileupload-loading {
display: block;
}
 
/* Fix for IE 6: */
* html .fileinput-button {
line-height: 24px;
margin: 1px -3px 0 0;
}
 
/* Fix for IE 7: */
* + html .fileinput-button {
line-height: 22px;
margin: 1px 0 0 0;
}
 
.files .delete input[type="checkbox"] {  
visibility: hidden;  
}  
  
@media (max-width: 767px) {
.files .btn span {
display: none;
}
.files .preview * {
width: 40px;
}
.files .name * {
width: 80px;
display: inline-block;
word-wrap: break-word;
}
.files .progress {
width: 20px;
}
.files .delete {
width: 60px;
}
}