.overlay-target {
    position: relative;
}

.overlay {
    height: 100%;
    left: 0;
    position: absolute;
    right: 0;
    top: 0;
}

/* @group Drag and drop */

.dnd-overlay:before {
    content: "Drop files here to add them as attachments";
    font-size: 150%;
    font-weight: bold;
    position: relative;
    top: 40%;
    vertical-align: middle;
}

.dnd-overlay {
    background-color: #F5F5F5;
    border: 4px dashed #A1A1A1;
    opacity: 0.9;
    text-align: center;
    visibility: hidden;
    z-index: 100;
}

.dnd-overlay.in {
    visibility: visible;
}

.dnd-overlay.in.active {
    background-color: #E0ECFF;
    border: 4px dashed #3366CC;
}

/* @end */