/*
 * Default Layout Theme
 *
 * Created for jquery.layout 
 *
 * Copyright (c) 2010 
 *   Fabrizio Balliano (http://www.fabrizioballiano.net)
 *   Kevin Dalman (http://allpro.net)
 *
 * Dual licensed under the GPL (http://www.gnu.org/licenses/gpl.html)
 * and MIT (http://www.opensource.org/licenses/mit-license.php) licenses.
 *
 * Last Updated: 2010-02-10
 * NOTE: For best code readability, view this with a fixed-space font and tabs equal to 4-chars
 */

/*
 *	UTILITY CLASSES
 *	Must come AFTER pane-class above so will override
 *	These classes are NOT auto-generated and are NOT used by Layout
 */
.layout-child-container,
.layout-content-container {
	padding:	0;
	overflow:	hidden;
}
.layout-child-container {
	border:		0; /* remove border because inner-layout-panes probably have borders */
}
.layout-scroll {
	overflow:	auto;
}
.layout-hide {
	display:	none;
}

/*
 *	RESIZER-BARS
 */
.ui-layout-resizer	{ /* all 'resizer-bars' */
	background:		#DDD;
	border:			1px solid #BBB;
	border-width:	0;
	}
	.ui-layout-resizer-drag {		/* REAL resizer while resize in progress */
	}
	.ui-layout-resizer-hover	{	/* affects both open and closed states */
	}
	/* NOTE: It looks best when 'hover' and 'dragging' are set to the same color,
		otherwise color shifts while dragging when bar can't keep up with mouse */
	.ui-layout-resizer-open-hover ,	/* hover-color to 'resize' */
	.ui-layout-resizer-dragging {	/* resizer beging 'dragging' */
		background: #C4E1A4;
	}
	.ui-layout-resizer-dragging {	/* CLONED resizer being dragged */
		border: 	 1px solid #BBB;
	}
	.ui-layout-resizer-north-dragging,
	.ui-layout-resizer-south-dragging {
		border-width:	1px 0;
	}
	.ui-layout-resizer-west-dragging,
	.ui-layout-resizer-east-dragging {
		border-width:	0 1px;
	}
	/* NOTE: Add a 'dragging-limit' color to provide visual feedback when resizer hits min/max size limits */
	.ui-layout-resizer-dragging-limit {	/* CLONED resizer at min or max size-limit */
		background: #E1A4A4; /* red */
	}

	.ui-layout-resizer-closed-hover	{ /* hover-color to 'slide open' */
		background: #EBD5AA;
	}
	.ui-layout-resizer-sliding {	/* resizer when pane is 'slid open' */
		opacity: .10; /* show only a slight shadow */
		filter:  alpha(opacity=10);
		}
		.ui-layout-resizer-sliding-hover {	/* sliding resizer - hover */
			opacity: 1.00; /* on-hover, show the resizer-bar normally */
			filter:  alpha(opacity=100);
		}
		/* sliding resizer - add 'outside-border' to resizer on-hover 
		 * this sample illustrates how to target specific panes and states */
		.ui-layout-resizer-north-sliding-hover	{ border-bottom-width:	1px; }
		.ui-layout-resizer-south-sliding-hover	{ border-top-width:		1px; }
		.ui-layout-resizer-west-sliding-hover	{ border-right-width:	1px; }
		.ui-layout-resizer-east-sliding-hover	{ border-left-width:	1px; }

/*
 *	TOGGLER-BUTTONS
 */
.ui-layout-toggler {
	border: 1px solid #BBB; /* match pane-border */
	background-color: #BBB;
	}
	.ui-layout-resizer-hover .ui-layout-toggler {
		opacity: .60;
		filter:  alpha(opacity=60);
	}
	.ui-layout-toggler-hover , /* need when NOT resizable */
	.ui-layout-resizer-hover .ui-layout-toggler-hover { /* need specificity when IS resizable */
		background-color: #FC6;
		opacity: 1.00;
		filter:  alpha(opacity=100);
	}
	.ui-layout-toggler-north ,
	.ui-layout-toggler-south {
		border-width: 0 1px; /* left/right borders */
	}
	.ui-layout-toggler-west ,
	.ui-layout-toggler-east {
		border-width: 1px 0; /* top/bottom borders */
	}
	/* hide the toggler-button when the pane is 'slid open' */
	.ui-layout-resizer-sliding  .ui-layout-toggler {
		display: none;
	}
	/*
	 *	style the text we put INSIDE the togglers
	 */
	.ui-layout-toggler .content {
		color:			#666;
		font-size:		12px;
		font-weight:	bold;
		width:			100%;
		padding-bottom:	0.35ex; /* to 'vertically center' text inside text-span */
	}

/*
 *	PANE-MASKS
 *	these styles are hard-coded on mask elems, but are also 
 *	included here as !important to ensure will overrides any generic styles
 */
.ui-layout-mask {
	border:		none !important;
	padding:	0 !important;
	margin:		0 !important;
	overflow:	hidden !important;
	position:	absolute !important;
	opacity:	0 !important;
	filter:		Alpha(Opacity="0") !important;
}
.ui-layout-mask-inside-pane { /* masks always inside pane EXCEPT when pane is an iframe */
	top:		0 !important;
	left:		0 !important;
	width:		100% !important;
	height:		100% !important;
}
div.ui-layout-mask {}		/* standard mask for iframes */
iframe.ui-layout-mask {}	/* extra mask for objects/applets */

/*
 *	Default printing styles
 */
@media print {
	/*
	 *	Unless you want to print the layout as it appears onscreen,
	 *	these html/body styles are needed to allow the content to 'flow'
	 */
	html {
		height:		auto !important;
		overflow:	visible !important;
	}
	body.ui-layout-container {
		position:	static !important;
		top:		auto !important;
		bottom:		auto !important;
		left:		auto !important;
		right:		auto !important;
		/* only IE6 has container width & height set by Layout */
		_width:		auto !important;
		_height:	auto !important;
	}
	.ui-layout-resizer, .ui-layout-toggler {
		display:	none !important;
	}
	/*
	 *	Default pane print styles disables positioning, borders and backgrounds.
	 *	You can modify these styles however it suit your needs.
	 */
	.ui-layout-pane {
		border:		none !important;
		background:	 transparent !important;
		position:	relative !important;
		top:		auto !important;
		bottom:		auto !important;
		left:		auto !important;
		right:		auto !important;
		width:		auto !important;
		height:		auto !important;
		overflow:	visible !important;
	}
}

/*
*	OUTER LAYOUT RESIZERS & TOGGLERS
*/

/* north-pane is not resizable
.resizer-north-dragging ,
.resizer-north:hover		{ background: url(../img/resizable-n.gif) repeat-x center; }*/
.resizer-south-dragging ,
.resizer-south:hover		{ background: url(../img/resizable-s.gif) repeat-x center; }

.resizer-west-dragging ,
.resizer-west-open:hover	{ background: url(../img/resizable-w.gif) repeat-y center; }
.resizer-east-dragging ,
.resizer-east-open:hover	{ background: url(../img/resizable-e.gif) repeat-y center; }

.resizer-west-open ,
.resizer-east-open {
	background-color: #999;
	opacity: 0.1;
	filter: alpha(opacity=10);
}
.resizer-west-open:hover ,
.resizer-east-open:hover {
	opacity: 1;
	filter: alpha(opacity=100);
}
.resizer-dragging {
	/* see draggable.opacity option
	opacity: 0.5;
	filter: alpha(opacity=50);
	*/
}
.resizer-dragging-limit	{ background: #FF3300 !important; }

/* IE6 * HACK - always show resizer graphics because IE6 cannot understand elem:hover */
/** html .resizer-north		{ background: url(../img/resizable-n.gif) repeat-x center !important; } */
* html .resizer-south		{ background: url(../img/resizable-s.gif) repeat-x center !important; }
* html .resizer-west-open	{ background: url(../img/resizable-w.gif) repeat-y center !important; }
* html .resizer-east-open	{ background: url(../img/resizable-e.gif) repeat-y center !important; }
/** html .resizer-north , */
* html .resizer-south ,
* html .resizer-west-open ,
* html .resizer-east-open {
	opacity: 0.1 !important;
	filter: alpha(opacity=10) !important;
}

/*
*	SIMPLE TOGGLER BUTTONS (used on Outer Layout North/South only)
*/

.toggler-north-open ,
.toggler-south-closed 		{ background: url(../img/toggle-up.gif) no-repeat center bottom; }
.toggler-north-closed ,
.toggler-south-open   		{ background: url(../img/toggle-dn.gif) no-repeat center top; }
/*
.toggler-east-closed ,
.toggler-west-open    { background: url(../img/toggle-lt.gif) no-repeat center right; }
.toggler-west-closed ,
.toggler-east-open    { background: url(../img/toggle-rt.gif) no-repeat center left; }
*/

/*
*	extJS-STYLE RESIZER/SLIDER-BAR (CLOSED)
*/
.ui-layout-resizer-west-closed ,
.ui-layout-resizer-east-closed {
	background: #D1E6FC url(../img/D1E6FC_40x100_textures_10_dots_medium_90.png) 0 0 repeat;
	border-top: 1px solid #777;
	border-bottom: 1px solid #777;
}
.ui-layout-resizer-west-closed:hover ,
.ui-layout-resizer-east-closed:hover {
	background: #D1E6FC;
}

/*
 *	extJS-STYLE TOGGLE & PIN BUTTONS
 *
 *	these 'extra buttons' are INSIDE the east/west panes
 */

/* CUSTOM pin/close buttons */
span.ui-layout-button-pin ,
span.ui-layout-button-close {
	position:	absolute;
	top:		0;
	width: 		20px;
	height:		20px;
	z-index:	2;
	display:	block;
	cursor: 	pointer;
}
span.ui-layout-button-close-west	{ left:	 0; }
span.ui-layout-button-close-east	{ right: 0; }
span.ui-layout-button-pin-west	{ right: 1px; }
span.ui-layout-button-pin-east	{ left:	 1px; }

/* CUSTOM pin-buttons */
span.ui-layout-button-pin-up 		  		{ background: url(../img/pin-up-off.gif) no-repeat center; }
span.ui-layout-button-pin-up:hover   		{ background: url(../img/pin-up-on.gif)  no-repeat center; }
span.ui-layout-button-pin-down 	  		{ background: url(../img/pin-dn-off.gif) no-repeat center; }
span.ui-layout-button-pin-down:hover 		{ background: url(../img/pin-dn-on.gif)  no-repeat center; }

/* CUSTOM close-buttons */
span.ui-layout-button-close-west			{ background: url(../img/go-lt-off.gif) no-repeat center; }
span.ui-layout-button-close-west:hover	{ background: url(../img/go-lt-on.gif)  no-repeat center; }
span.ui-layout-button-close-east			{ background: url(../img/go-rt-off.gif) no-repeat center; }
span.ui-layout-button-close-east:hover	{ background: url(../img/go-rt-on.gif)  no-repeat center; }

/* STANDARD toggler-buttons - when the east/west panes are 'closed' */
.ui-layout-toggler-west-closed		{ background: url(../img/go-rt-off.gif) no-repeat center; }
.ui-layout-toggler-west-closed:hover	{ background: url(../img/go-rt-on.gif)  no-repeat center; }
.ui-layout-toggler-east-closed		{ background: url(../img/go-lt-off.gif) no-repeat center; }
.ui-layout-toggler-east-closed:hover	{ background: url(../img/go-lt-on.gif)  no-repeat center; }

/*
*	OUTER LAYOUT RESIZERS & TOGGLERS
*/

/* north-pane is not resizable
.resizer-north-dragging ,
.resizer-north:hover		{ background: url(../img/resizable-n.gif) repeat-x center; }*/
.ui-layout-resizer-south-dragging ,
.ui-layout-resizer-south:hover		{ background: url(../img/resizable-s.gif) repeat-x center; }

.ui-layout-resizer-west-dragging ,
.ui-layout-resizer-west-open:hover	{ background: url(../img/resizable-w.gif) repeat-y center; }
.ui-layout-resizer-east-dragging ,
.ui-layout-resizer-east-open:hover	{ background: url(../img/resizable-e.gif) repeat-y center; }

.ui-layout-resizer-west-open ,
.ui-layout-resizer-east-open {
	background-color: #999;
	opacity: 0.1;
	filter: alpha(opacity=10);
}
.ui-layout-resizer-west-open:hover ,
.ui-layout-resizer-east-open:hover {
	opacity: 1;
	filter: alpha(opacity=100);
}
.ui-layout-resizer-dragging {
	/* see draggable.opacity option
	opacity: 0.5;
	filter: alpha(opacity=50);
	*/
}
.ui-layout-resizer-dragging-limit	{ background: #FF3300 !important; }

/* IE6 * HACK - always show resizer graphics because IE6 cannot understand elem:hover */
/** html .resizer-north		{ background: url(../img/resizable-n.gif) repeat-x center !important; } */
* html .ui-layout-resizer-south		{ background: url(../img/resizable-s.gif) repeat-x center !important; }
* html .ui-layout-resizer-west-open	{ background: url(../img/resizable-w.gif) repeat-y center !important; }
* html .ui-layout-resizer-east-open	{ background: url(../img/resizable-e.gif) repeat-y center !important; }
/** html .resizer-north , */
* html .ui-layout-resizer-south ,
* html .ui-layout-resizer-west-open ,
* html .ui-layout-resizer-east-open {
	opacity: 0.1 !important;
	filter: alpha(opacity=10) !important;
}


.pane ,				/* outer pane class */
.ui-layout-pane {	/* inner pane class */
	background-color: #FFF;
	border: 1px solid #BBB;
	padding: 0;/* alignment & padding is on the inner-divs */
	overflow: auto; /* will be auto-set to 'hidden' for any pane with a 'scrolling content div' */
}


/*
*	OUTER-LAYOUT PANE FORMATTING
*/
.pane-north ,
.pane-south ,
.pane-west ,
.pane-east {
	overflow:		hidden;
}
.pane-north {
	border-bottom:	none;
	}

.pane-center {
	/* show off the inner-layout inside the outer-center-pane*/
	background-color: #F6F6F6;
	padding: 15px; /* for outer layout */
}

/*
*	INNER-LAYOUT PANE FORMATTING
*/

#contlayout .ui-layout-pane {
	padding: 10px;
}
#contlayout .ui-layout-content {
	padding: 10px;
}
#contlayout .ui-layout-center h3 {
	padding: 5px;
	margin: 0;
}